You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@zeppelin.apache.org by mo...@apache.org on 2016/06/24 07:21:00 UTC

zeppelin git commit: [ZEPPELIN-936] Fix flaky test SparkRTest

Repository: zeppelin
Updated Branches:
  refs/heads/master 33fb93f81 -> 6497008cc


[ZEPPELIN-936] Fix flaky test SparkRTest

### What is this PR for?
This PR fixes test failure described in ZEPPELIN-936,
or hanging on SparkRTest

```
Spark version detected 1.6.1
23:52:30,005  INFO org.apache.zeppelin.notebook.Paragraph:252 - run paragraph 20160623-235230_1368989448 using r org.apache.zeppelin.interpreter.LazyOpenInterpreter5221ff81

No output has been received in the last 10 minutes, this potentially indicates a stalled build or something wrong with the build itself.

The build has been terminated
```

### What type of PR is it?
Hot Fix

### What is the Jira issue?
https://issues.apache.org/jira/browse/ZEPPELIN-936

Author: Lee moon soo <mo...@apache.org>

Closes #1078 from Leemoonsoo/disable_flaky_test and squashes the following commits:

4872d66 [Lee moon soo] trigger ci
b5b7b83 [Lee moon soo] trigger ci
4f75ade [Lee moon soo] trigger ci
31a247c [Lee moon soo] trigger ci
9183e2a [Lee moon soo] trigger ci
582b6e1 [Lee moon soo] reduce spark.cores.max on testing


Project: http://git-wip-us.apache.org/repos/asf/zeppelin/repo
Commit: http://git-wip-us.apache.org/repos/asf/zeppelin/commit/6497008c
Tree: http://git-wip-us.apache.org/repos/asf/zeppelin/tree/6497008c
Diff: http://git-wip-us.apache.org/repos/asf/zeppelin/diff/6497008c

Branch: refs/heads/master
Commit: 6497008cc309f88bd8816c3c3e374887db524aae
Parents: 33fb93f
Author: Lee moon soo <mo...@apache.org>
Authored: Thu Jun 23 23:52:29 2016 -0700
Committer: Lee moon soo <mo...@apache.org>
Committed: Fri Jun 24 00:22:55 2016 -0700

----------------------------------------------------------------------
 .../test/java/org/apache/zeppelin/rest/AbstractTestRestApi.java   | 3 ++-
 1 file changed, 2 insertions(+), 1 deletion(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/zeppelin/blob/6497008c/zeppelin-server/src/test/java/org/apache/zeppelin/rest/AbstractTestRestApi.java
----------------------------------------------------------------------
diff --git a/zeppelin-server/src/test/java/org/apache/zeppelin/rest/AbstractTestRestApi.java b/zeppelin-server/src/test/java/org/apache/zeppelin/rest/AbstractTestRestApi.java
index 5ea3c09..7bedd28 100644
--- a/zeppelin-server/src/test/java/org/apache/zeppelin/rest/AbstractTestRestApi.java
+++ b/zeppelin-server/src/test/java/org/apache/zeppelin/rest/AbstractTestRestApi.java
@@ -127,8 +127,9 @@ public abstract class AbstractTestRestApi {
           }
         }
 
         // set spark master
         sparkIntpSetting.getProperties().setProperty("master", "spark://" + getHostname() + ":7071");
+        sparkIntpSetting.getProperties().setProperty("spark.cores.max", "2");
 
         // set spark home for pyspark
         sparkIntpSetting.getProperties().setProperty("spark.home", getSparkHome());
@@ -127,8 +127,9 @@ public abstract class AbstractTestRestApi {
         }
 
-        // set spark master
+        // set spark master and other properties
         sparkIntpSetting.getProperties().setProperty("master", "spark://" + getHostname() + ":7071");